# Agile toolkit

[![PyPI version](https://badge.fury.io/py/agile-toolkit.svg)](https://badge.fury.io/py/agile-toolkit)

[![CircleCI](https://circleci.com/gh/lendingblock/agile-toolkit.svg?style=svg)](https://circleci.com/gh/lendingblock/agile-toolkit)

[![codecov](https://codecov.io/gh/lendingblock/agile-toolkit/branch/master/graph/badge.svg)](https://codecov.io/gh/lendingblock/agile-toolkit)
